/*
 * Copyright 2010 James Pether Sörling
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: ItsYourParliamentEuApi.java 4350 2010-09-02 22:12:44Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/service.external.itsyourparliament-1.0.0-beta-1/src/main/java/com/hack23/cia/service/external/itsyourparliament/api/ItsYourParliamentEuApi.java $
*/
package com.hack23.cia.service.external.itsyourparliament.api;

import java.math.BigInteger;
import java.util.List;

import com.hack23.cia.model.external.itsyourparliament.countries.impl.Countrydetails;
import com.hack23.cia.model.external.itsyourparliament.countryinfo.impl.CountryinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.mepinfo.impl.MepinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.voteinfo.impl.VoteinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.votes.impl.VotesEuData;

/**
 * The Interface ItsYourParliamentEuApi.
 */
public interface ItsYourParliamentEuApi {
	
	/**
	 * Gets the countries.
	 * 
	 * @param accessKey
	 *            the access key
	 * @param current
	 *            the current
	 * @return the countries
	 * @throws Exception
	 *             the exception
	 */
	List<Countrydetails> getCountries(String accessKey,boolean current) throws Exception;
	
	/**
	 * Gets the country info.
	 * 
	 * @param id
	 *            the id
	 * @param accessKey
	 *            the access key
	 * @param current
	 *            the current
	 * @return the country info
	 * @throws Exception
	 *             the exception
	 */
	CountryinfoEuElement getCountryInfo(BigInteger id,String accessKey,boolean current) throws Exception;

	/**
	 * Gets the mep info.
	 * 
	 * @param mepId
	 *            the mep id
	 * @param accessKey
	 *            the access key
	 * @param current
	 *            the current
	 * @return the mep info
	 * @throws Exception
	 *             the exception
	 */
	MepinfoEuElement getMepInfo(String mepId,String accessKey,boolean current) throws Exception;

	/**
	 * Gets the vote info.
	 * 
	 * @param voteId
	 *            the vote id
	 * @param accessKey
	 *            the access key
	 * @param current
	 *            the current
	 * @return the vote info
	 * @throws Exception
	 *             the exception
	 */
	VoteinfoEuElement getVoteInfo(String voteId, String accessKey,boolean current) throws Exception;

	/**
	 * Gets the votes.
	 * 
	 * @param year
	 *            the year
	 * @param accessKey
	 *            the access key
	 * @param current
	 *            the current
	 * @return the votes
	 * @throws Exception
	 *             the exception
	 */
	VotesEuData getVotes(String year,String accessKey,boolean current) throws Exception;

}
